@@ -118,7 +118,7 @@ model_terms_clme <- function( formula, data ){
     U  <- t( as.matrix(clme_terms$reTrms$Zt) )
     
     dframe  <- clme_terms$fr
-    REnames <- colnames(clme_terms$reTrms$flist)
+    REnames <- names(clme_terms$reTrms$flist)
     REidx   <- clme_terms$reTrms$Lind
     
   }
@@ -202,9 +202,9 @@ as.clme <- function( x , ... ){
     }
     
     if( !is.matrix(x$cov.theta) || !is.numeric(x$cov.theta) ||
-          nrow(x$cov.theta) != ncol(x$cov.theta) ||
-          nrow(x$cov.theta) != length(x$theta)   ||
-          sum(sum(abs(x$cov.theta - t(x$cov.theta)))) > sqrt(.Machine$double.eps) ){
+        nrow(x$cov.theta) != ncol(x$cov.theta) ||
+        nrow(x$cov.theta) != length(x$theta)   ||
+        sum(sum(abs(x$cov.theta - t(x$cov.theta)))) > sqrt(.Machine$double.eps) ){
       err.flag    <- 1
       flagCov     <- " cov.theta must be square, symmetric, numeric matrix with dimensions equal to length of theta\n"
       x$cov.theta <- matrix( numeric(0) , nrow=length(x$theta) , ncol=length(x$theta) )
@@ -1100,10 +1100,12 @@ residuals.summary.clme <- function( object, type="FM", ... ){
 #'          
 #' sigma( clme.out )
 #' 
-#' @importFrom lme4 sigma
+#' 
+#' @importFrom stats sigma
 #' @method sigma clme
 #' @export
 #' 
+# WAS IMPORTING sigma FROM lme4
 sigma.clme <- function( object, ...){
   return( object$ssq )
 }
@@ -1203,6 +1205,9 @@ VarCorr.clme <- function(x, sigma, rdig ){
     stop("'x' is not of class clme")
   } else{
     varcomps <- matrix( sqrt(c(x$tsq, x$ssq )), ncol=1 )
+    if( is.null(names(x$tsq)) ){
+      names(x$tsq) <- paste0( "tau_", 1:length(x$tsq) )
+    }
     rnames   <- c( "Source", names(x$tsq), names(x$ssq) )
     rownames(varcomps) <- rnames[-1]
     colnames(varcomps) <- "Std. Error"
@@ -1247,7 +1252,7 @@ print.varcorr_clme <- function(object, rdig=5, ...){
   rnames   <- c( "Source", rownames( object ) )
   rnames   <- str_pad(rnames, width=max(nchar(rnames)), side = "right", pad = " ")
   vars     <- format( object , digits=rdig )
-
+  
   cat( rnames[1], "\t" , "Variance" )
   for( ii in 1:length(vars) ){
     cat( "\n", rnames[ii+1], "\t" , vars[ii] )
